/*
 * Copyright (C) 2019 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.settings.deviceinfo.firmwareversion;

import android.content.Context;
import android.os.SystemProperties;

import androidx.annotation.VisibleForTesting;

import com.android.settings.R;
import com.android.settings.Utils;
import com.android.settings.core.BasePreferenceController;

public class BasebandVersionPreferenceController extends BasePreferenceController {

    @VisibleForTesting
    static final String BASEBAND_PROPERTY = "gsm.version.baseband";
    private final Context mContext;

    public BasebandVersionPreferenceController(Context context, String preferenceKey) {
        super(context, preferenceKey);
        mContext = context;
    }

    @Override
    public int getAvailabilityStatus() {
        return !Utils.isWifiOnly(mContext) ? AVAILABLE : UNSUPPORTED_ON_DEVICE;
    }

    @Override
    public CharSequence getSummary() {
        if (Utils.isSupportCTPA(mContext.getApplicationContext())) {
            String baseBands = SystemProperties.get(BASEBAND_PROPERTY,
                    mContext.getString(R.string.device_info_default));
            if (null != baseBands) {
                String[] baseBandArray = baseBands.split(",");
                if ((baseBandArray != null) && (baseBandArray.length > 0)) {
                    return baseBandArray[0];
                }
            }
        }
        return SystemProperties.get(BASEBAND_PROPERTY,
                mContext.getString(R.string.device_info_default));
    }
}
